powered by
na.rm is similar to na.omit but allows to specify a list of variables to take into account.
na.rm
na.rm(x, v = NULL)
a data frame
a list of variables
Joseph Larmarange <[email protected]>
If v is not specified, the result of na.rm will be the same as na.omit. If a list of variables is specified through v, only observations with a missing value (NA) for one of the specified variables will be removed from x. See examples.
v
NA
x
na.omit
df <- data.frame(x = c(1, 2, 3), y = c(0, 10, NA), z = c("a", NA, "b")) df na.omit(df) na.rm(df) na.rm(df, c("x", "y")) na.rm(df, "z")
Run the code above in your browser using DataLab