powered by
This function quickly loads one or more packages, installing them quietly if necessary.
qload(..., load = TRUE, silent = TRUE)
The result is a list of packages cited in the scripts.
the packages to load/install. Packages are loaded with library and installed first with install.packages if necessary.
library
install.packages
load the packages. Set to FALSE to just install any missing packages. Defaults to TRUE.
FALSE
TRUE
keep output as silent as possible. Defaults to TRUE.
François Briatte <[email protected]>
The function probably requires R 3.0.0 or above to make use of the quiet argument when calling install.packages. It is not clear what the argument previously achieved in older versions of R.
quiet
qscan, install.packages, library
qscan
qload("questionr") qload("questionr", silent = FALSE)
Run the code above in your browser using DataLab